@@ -1,5 +1,5 @@
 ﻿/*
-Copyright (c) 2003-2010, CKSource - Frederico Knabben. All rights reserved.
+Copyright (c) 2003-2011, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.html or http://ckeditor.com/license
 */
 
@@ -56,6 +56,7 @@ CKEDITOR.lang['km'] =
 	superscript		: 'អក្សរតូចលើ',
 	horizontalrule	: 'បន្ថែមបន្ទាត់ផ្តេក',
 	pagebreak		: 'បន្ថែម ការផ្តាច់ទំព័រ',
+	pagebreakAlt		: 'Page Break', // MISSING
 	unlink			: 'លប់ឈ្នាប់',
 	undo			: 'សារឡើងវិញ',
 	redo			: 'ធ្វើឡើងវិញ',
@@ -105,6 +106,21 @@ CKEDITOR.lang['km'] =
 		targetTop		: 'Topmost Window (_top)', // MISSING
 		targetSelf		: 'Same Window (_self)', // MISSING
 		targetParent	: 'Parent Window (_parent)', // MISSING
+		langDirLTR		: 'Left to Right (LTR)', // MISSING
+		langDirRTL		: 'Right to Left (RTL)', // MISSING
+		styles			: 'Style', // MISSING
+		cssClasses		: 'Stylesheet Classes', // MISSING
+		width			: 'ទទឹង',
+		height			: 'កំពស់',
+		align			: 'កំណត់ទីតាំង',
+		alignLeft		: 'ខាងឆ្វង',
+		alignRight		: 'ខាងស្តាំ',
+		alignCenter		: 'កណ្តាល',
+		alignTop		: 'ខាងលើ',
+		alignMiddle		: 'កណ្តាល',
+		alignBottom		: 'ខាងក្រោម',
+		invalidHeight	: 'Height must be a number.', // MISSING
+		invalidWidth	: 'Width must be a number.', // MISSING
 
 		// Put the voice-only part of the label in the span.
 		unavailable		: '%1<span class="cke_accessibility">, unavailable</span>' // MISSING
@@ -151,9 +167,7 @@ CKEDITOR.lang['km'] =
 		popupFullScreen	: 'អេក្រុងពេញ(IE)',
 		popupScrollBars	: 'របា ទាញ',
 		popupDependent	: 'អាស្រ័យលើ (Netscape)',
-		popupWidth		: 'ទទឹង',
 		popupLeft		: 'ទីតាំងខាងឆ្វេង',
-		popupHeight		: 'កំពស់',
 		popupTop		: 'ទីតាំងខាងលើ',
 		id				: 'Id', // MISSING
 		langDir			: 'ទិសដៅភាសា',
@@ -196,6 +210,7 @@ CKEDITOR.lang['km'] =
 		bulletedTitle		: 'Bulleted List Properties', // MISSING
 		type				: 'Type', // MISSING
 		start				: 'Start', // MISSING
+		validateStartNumber				:'List start number must be a whole number.', // MISSING
 		circle				: 'Circle', // MISSING
 		disc				: 'Disc', // MISSING
 		square				: 'Square', // MISSING
@@ -238,15 +253,9 @@ CKEDITOR.lang['km'] =
 		rows		: 'ជួរផ្តេក',
 		columns		: 'ជួរឈរ',
 		border		: 'ទំហំស៊ុម',
-		align		: 'ការកំណត់ទីតាំង',
-		alignLeft	: 'ខាងឆ្វេង',
-		alignCenter	: 'កណ្តាល',
-		alignRight	: 'ខាងស្តាំ',
-		width		: 'ទទឹង',
 		widthPx		: 'ភីកសែល',
 		widthPc		: 'ភាគរយ',
 		widthUnit	: 'width unit', // MISSING
-		height		: 'កំពស់',
 		cellSpace	: 'គំលាតសែល',
 		cellPad		: 'គែមសែល',
 		caption		: 'ចំណងជើង',
@@ -282,9 +291,6 @@ CKEDITOR.lang['km'] =
 			wordWrap		: 'Word Wrap', // MISSING
 			hAlign			: 'Horizontal Alignment', // MISSING
 			vAlign			: 'Vertical Alignment', // MISSING
-			alignTop		: 'Top', // MISSING
-			alignMiddle		: 'Middle', // MISSING
-			alignBottom		: 'Bottom', // MISSING
 			alignBaseline	: 'Baseline', // MISSING
 			bgColor			: 'Background Color', // MISSING
 			borderColor		: 'Border Color', // MISSING
@@ -405,24 +411,17 @@ CKEDITOR.lang['km'] =
 		btnUpload	: 'បញ្ជូនទៅកាន់ម៉ាស៊ីនផ្តល់សេវា',
 		upload		: 'ទាញយក',
 		alt			: 'អត្ថបទជំនួស',
-		width		: 'ទទឹង',
-		height		: 'កំពស់',
 		lockRatio	: 'អត្រាឡុក',
 		unlockRatio	: 'Unlock Ratio', // MISSING
 		resetSize	: 'កំណត់ទំហំឡើងវិញ',
 		border		: 'ស៊ុម',
 		hSpace		: 'គំលាតទទឹង',
 		vSpace		: 'គំលាតបណ្តោយ',
-		align		: 'កំណត់ទីតាំង',
-		alignLeft	: 'ខាងឆ្វង',
-		alignRight	: 'ខាងស្តាំ',
 		alertUrl	: 'សូមសរសេរងាស័យដ្ឋានរបស់រូបភាព',
 		linkTab		: 'ឈ្នាប់',
 		button2Img	: 'Do you want to transform the selected image button on a simple image?', // MISSING
 		img2Button	: 'Do you want to transform the selected image on a image button?', // MISSING
 		urlMissing	: 'Image source URL is missing.', // MISSING
-		validateWidth	: 'Width must be a whole number.', // MISSING
-		validateHeight	: 'Height must be a whole number.', // MISSING
 		validateBorder	: 'Border must be a whole number.', // MISSING
 		validateHSpace	: 'HSpace must be a whole number.', // MISSING
 		validateVSpace	: 'VSpace must be a whole number.' // MISSING
@@ -446,16 +445,10 @@ CKEDITOR.lang['km'] =
 		accessAlways	: 'Always', // MISSING
 		accessSameDomain: 'Same domain', // MISSING
 		accessNever		: 'Never', // MISSING
-		align			: 'កំណត់ទីតាំង',
-		alignLeft		: 'ខាងឆ្វង',
 		alignAbsBottom	: 'Abs Bottom', // MISSING
 		alignAbsMiddle	: 'Abs Middle', // MISSING
 		alignBaseline	: 'បន្ទាត់ជាមូលដ្ឋាន',
-		alignBottom		: 'ខាងក្រោម',
-		alignMiddle		: 'កណ្តាល',
-		alignRight		: 'ខាងស្តាំ',
 		alignTextTop	: 'លើអត្ថបទ',
-		alignTop		: 'ខាងលើ',
 		quality			: 'Quality', // MISSING
 		qualityBest		: 'Best', // MISSING
 		qualityHigh		: 'High', // MISSING
@@ -469,13 +462,9 @@ CKEDITOR.lang['km'] =
 		windowMode		: 'Window mode', // MISSING
 		flashvars		: 'Variables for Flash', // MISSING
 		bgcolor			: 'ពណ៌ផ្ទៃខាងក្រោយ',
-		width			: 'ទទឹង',
-		height			: 'កំពស់',
 		hSpace			: 'គំលាតទទឹង',
 		vSpace			: 'គំលាតបណ្តោយ',
 		validateSrc		: 'សូមសរសេរ អាស័យដ្ឋាន URL',
-		validateWidth	: 'Width must be a number.', // MISSING
-		validateHeight	: 'Height must be a number.', // MISSING
 		validateHSpace	: 'HSpace must be a number.', // MISSING
 		validateVSpace	: 'VSpace must be a number.' // MISSING
 	},
@@ -610,6 +599,15 @@ CKEDITOR.lang['km'] =
 		remove				: 'Remove Div' // MISSING
   	},
 
+	iframe :
+	{
+		title		: 'IFrame Properties', // MISSING
+		toolbar		: 'IFrame', // MISSING
+		noUrl		: 'Please type the iframe URL', // MISSING
+		scrolling	: 'Enable scrollbars', // MISSING
+		border		: 'Show frame border' // MISSING
+	},
+
 	font :
 	{
 		label		: 'ហ្វុង',
@@ -642,7 +640,7 @@ CKEDITOR.lang['km'] =
 		'008080' : 'Teal', // MISSING
 		'000080' : 'Navy', // MISSING
 		'4B0082' : 'Indigo', // MISSING
-		'696969' : 'Dim Gray', // MISSING
+		'696969' : 'Dark Gray', // MISSING
 		'B22222' : 'Fire Brick', // MISSING
 		'A52A2A' : 'Brown', // MISSING
 		'DAA520' : 'Golden Rod', // MISSING
@@ -658,7 +656,7 @@ CKEDITOR.lang['km'] =
 		'0FF' : 'Cyan', // MISSING
 		'00F' : 'Blue', // MISSING
 		'EE82EE' : 'Violet', // MISSING
-		'A9A9A9' : 'Dark Gray', // MISSING
+		'A9A9A9' : 'Dim Gray', // MISSING
 		'FFA07A' : 'Light Salmon', // MISSING
 		'FFA500' : 'Orange', // MISSING
 		'FFFF00' : 'Yellow', // MISSING
@@ -707,7 +705,7 @@ CKEDITOR.lang['km'] =
 		dic_restore		: 'Restore', // MISSING
 		dic_delete		: 'Delete', // MISSING
 		dic_rename		: 'Rename', // MISSING
-		dic_info		: 'Initially the User Dictionary is stored in a Cookie. However, Cookies are limited in size. When the User Dictionary grows to a point where it cannot be stored in a Cookie, then the dictionary may be stored on our server. To store your personal dictionary on our server you should specify a name for your dictionary. If you already have a stored dictionary, please type it\'s name and click the Restore button.', // MISSING
+		dic_info		: 'Initially the User Dictionary is stored in a Cookie. However, Cookies are limited in size. When the User Dictionary grows to a point where it cannot be stored in a Cookie, then the dictionary may be stored on our server. To store your personal dictionary on our server you should specify a name for your dictionary. If you already have a stored dictionary, please type its name and click the Restore button.', // MISSING
 
 		aboutTab		: 'About' // MISSING
 	},
@@ -725,10 +723,11 @@ CKEDITOR.lang['km'] =
 
 	fakeobjects :
 	{
-		anchor	: 'Anchor', // MISSING
-		flash	: 'Flash Animation', // MISSING
-		div		: 'Page Break', // MISSING
-		unknown	: 'Unknown Object' // MISSING
+		anchor		: 'Anchor', // MISSING
+		flash		: 'Flash Animation', // MISSING
+		iframe		: 'IFrame', // MISSING
+		hiddenfield	: 'Hidden Field', // MISSING
+		unknown		: 'Unknown Object' // MISSING
 	},
 
 	resize : 'Drag to resize', // MISSING
@@ -743,5 +742,11 @@ CKEDITOR.lang['km'] =
 	},
 
 	toolbarCollapse	: 'Collapse Toolbar', // MISSING
-	toolbarExpand	: 'Expand Toolbar' // MISSING
+	toolbarExpand	: 'Expand Toolbar', // MISSING
+
+	bidi :
+	{
+		ltr : 'Text direction from left to right', // MISSING
+		rtl : 'Text direction from right to left' // MISSING
+	}
 };
